@@ -6,8 +6,7 @@ from typing import Any, Callable, Dict, List, Optional, Union, ContextManager
 import importlib
 
 from requests import get, post  # As for API
-import selenium
-import selenium.common.exceptions
+import selenium.common.exceptions as selenium_exceptions
 from bs4 import BeautifulSoup
 from selenium.webdriver.common.by import By
 from selenium.webdriver.remote import webdriver, webelement
@@ -43,10 +42,11 @@ def get_browser(
 ) -> str:
     def _(browser_name: BrowserType):
         try:
-            importlib.import_module(
-                browser_name.value.lower(), "selenium.webdriver"
-            ).webdriver.WebDriver().close()
-        except selenium.common.exceptions.WebDriverException:
+            getattr(
+                importlib.import_module(".webdriver", "selenium"),
+                browser_name.value,
+            )().close()
+        except selenium_exceptions.WebDriverException:
             return None
         else:
             return browser_name
@@ -132,7 +132,7 @@ class BrowserContext:
         """
         try:
             return Element(self._get_wait_up_to(up_to).until(until))
-        except selenium.common.exceptions.TimeoutException as error:
+        except selenium_exceptions.TimeoutException as error:
             raise TimeoutError(
                 f"Could not find element under {up_to} seconds"
             ) from error
